pub struct FlatConfig { /* private fields */ }Expand description
Implementations
Sourceimpl FlatConfig
impl FlatConfig
Sourcepub fn has_rule(&self, key: impl AsRef<str>) -> bool
pub fn has_rule(&self, key: impl AsRef<str>) -> bool
Check if a rule exists in the configuration.
pub fn set_rule_enabled(&mut self, key: impl ToString, val: bool)
Sourcepub fn unset_rule_enabled(&mut self, key: impl AsRef<str>)
pub fn unset_rule_enabled(&mut self, key: impl AsRef<str>)
Remove any configuration attached to a rule. This allows it to assume its default (curated) state.
pub fn set_rule_enabled_if_unset(&mut self, key: impl AsRef<str>, val: bool)
pub fn is_rule_enabled(&self, key: &str) -> bool
Sourcepub fn merge_from(&mut self, other: FlatConfig)
pub fn merge_from(&mut self, other: FlatConfig)
Merge the contents of another FlatConfig into this one.
Conflicting keys will be overridden by the value in the other group.
Sourcepub fn fill_with_curated(&mut self)
pub fn fill_with_curated(&mut self)
Fill the group with the values for the curated lint group.
pub fn new_curated() -> Self