StructuredConfig

Struct StructuredConfig 

pub struct StructuredConfig {
    pub settings: Vec<Setting>,
}
A structure for defining which rules to be enabled or disabled in a LintGroup.

So named because it represents a more structured view for organizing rules. Designed to be something that can be converted into a FlatConfig at runtime before being passed to an actual LintGroup

Fields

settings: Vec<Setting>

Implementations

Source

impl StructuredConfig

pub fn curated() -> Self

Build the curated structured config, including labels.

pub fn validate(&self) -> bool

Validate that the structure of the settings is valid. Returns true if it is valid and false otherwise.

pub fn to_flat_config(&self) -> Option<FlatConfig>

Creates a FlatConfig that represents these settings. Will return None if self is invalid.

pub fn copy_from_flat_config(&mut self, config: &FlatConfig)

Fills in the relevant values from a FlatConfig according to the relevant name fields.