MutableDictionary

Struct MutableDictionary 

pub struct MutableDictionary { /* private fields */ }
A basic dictionary that allows words to be added after instantiating. This is useful for user and file dictionaries that may change at runtime.

For immutable use-cases that require fuzzy lookups, such as the curated dictionary, prefer super::FstDictionary, as it is much faster.

To combine the contents of multiple dictionaries, regardless of type, use super::MergedDictionary.

Implementations

Source

impl MutableDictionary

pub fn new() -> Self

pub fn from_rune_files(word_list: &str, attr_list: &str) -> Result<Self, Error>

pub fn curated() -> Arc<Self>

Create a dictionary from the curated dictionary included in the Harper binary. Consider using super::FstDictionary::curated() instead, as it is more performant for spellchecking.

pub fn extend_words( &mut self, words: impl IntoIterator<Item = (impl AsRef<[char]>, DictWordMetadata)>, )

Appends words to the dictionary. It is significantly faster to append many words with one call than many distinct calls to this function.

pub fn append_word( &mut self, word: impl AsRef<[char]>, metadata: DictWordMetadata, )

Append a single word to the dictionary.

If you are appending many words, consider using Self::extend_words instead.

pub fn append_word_str(&mut self, word: &str, metadata: DictWordMetadata)

Append a single string to the dictionary.

If you are appending many words, consider using Self::extend_words instead.