WordId

Struct WordId 

pub struct WordId { /* private fields */ }
An identifier for a particular word.

It works by hashing the word it represents, normalized to lowercase. It is meant for situations where you need to refer to a word (or a collection of words), without storing all of accompanying data (like spelling or metadata).

Implementations

Source

impl WordId

pub fn from_word_chars(chars: impl AsRef<[char]>) -> Self

Create a Word ID from a character slice.

pub fn from_word_str(text: impl AsRef<str>) -> Self

Create a word ID from a string. Requires allocation, so use sparingly.