pub struct Document { /* private fields */ }Expand description
A document containing some amount of lexed and parsed English text.
Implementations
Sourceimpl Document
impl Document
Sourcepub fn token_indices_intersecting(&self, span: Span<char>) -> Vec<usize>
pub fn token_indices_intersecting(&self, span: Span<char>) -> Vec<usize>
Locate all the tokens that intersect a provided span.
Desperately needs optimization.
Sourcepub fn fat_tokens_intersecting(&self, span: Span<char>) -> Vec<FatToken>
pub fn fat_tokens_intersecting(&self, span: Span<char>) -> Vec<FatToken>
Locate all the tokens that intersect a provided span and convert them to FatTokens.
Desperately needs optimization.
Sourcepub fn new(
text: &str,
parser: &impl Parser,
dictionary: &impl Dictionary,
) -> Self
pub fn new( text: &str, parser: &impl Parser, dictionary: &impl Dictionary, ) -> Self
Lexes and parses text to produce a document using a provided language parser and dictionary.
Sourcepub fn new_curated(text: &str, parser: &impl Parser) -> Self
pub fn new_curated(text: &str, parser: &impl Parser) -> Self
Lexes and parses text to produce a document using a provided language parser and the included curated dictionary.
Sourcepub fn new_from_vec(
source: Lrc<Vec<char>>,
parser: &impl Parser,
dictionary: &impl Dictionary,
) -> Self
pub fn new_from_vec( source: Lrc<Vec<char>>, parser: &impl Parser, dictionary: &impl Dictionary, ) -> Self
Lexes and parses text to produce a document using a provided language parser and dictionary.
Sourcepub fn new_plain_english_curated(text: &str) -> Self
pub fn new_plain_english_curated(text: &str) -> Self
Parse text to produce a document using the built-in PlainEnglish
parser and curated dictionary.
Sourcepub fn new_plain_english(text: &str, dictionary: &impl Dictionary) -> Self
pub fn new_plain_english(text: &str, dictionary: &impl Dictionary) -> Self
Parse text to produce a document using the built-in PlainEnglish
parser and a provided dictionary.
Sourcepub fn new_markdown_curated(
text: &str,
markdown_options: MarkdownOptions,
) -> Self
pub fn new_markdown_curated( text: &str, markdown_options: MarkdownOptions, ) -> Self
Parse text to produce a document using the built-in Markdown parser
and curated dictionary.
Sourcepub fn new_markdown_default_curated(text: &str) -> Self
pub fn new_markdown_default_curated(text: &str) -> Self
Parse text to produce a document using the built-in Markdown parser
and curated dictionary with the default Markdown configuration.
Sourcepub fn new_markdown(
text: &str,
markdown_options: MarkdownOptions,
dictionary: &impl Dictionary,
) -> Self
pub fn new_markdown( text: &str, markdown_options: MarkdownOptions, dictionary: &impl Dictionary, ) -> Self
Parse text to produce a document using the built-in PlainEnglish
parser and the curated dictionary.
Sourcepub fn new_markdown_default(text: &str, dictionary: &impl Dictionary) -> Self
pub fn new_markdown_default(text: &str, dictionary: &impl Dictionary) -> Self
Parse text to produce a document using the built-in PlainEnglish
parser and the curated dictionary with the default Markdown configuration.
pub fn get_token_at_char_index(&self, char_index: usize) -> Option<&Token>
Sourcepub fn get_token(&self, index: usize) -> Option<&Token>
pub fn get_token(&self, index: usize) -> Option<&Token>
Defensively attempt to grab a specific token.
Sourcepub fn get_token_offset(&self, base: usize, offset: isize) -> Option<&Token>
pub fn get_token_offset(&self, base: usize, offset: isize) -> Option<&Token>
Get a token at a signed offset from a base index, or None if out of bounds.
Sourcepub fn tokens(&self) -> impl Iterator<Item = &Token> + '_
pub fn tokens(&self) -> impl Iterator<Item = &Token> + '_
Get an iterator over all the tokens contained in the document.
pub fn iter_nominal_phrases(&self) -> impl Iterator<Item = &[Token]>
Sourcepub fn fat_tokens(&self) -> impl Iterator<Item = FatToken> + '_
pub fn fat_tokens(&self) -> impl Iterator<Item = FatToken> + '_
Get an iterator over all the tokens contained in the document.
Sourcepub fn get_next_word_from_offset(
&self,
base: usize,
offset: isize,
) -> Option<&Token>
pub fn get_next_word_from_offset( &self, base: usize, offset: isize, ) -> Option<&Token>
Get the next or previous word token relative to a base index, if separated by whitespace. Returns None if the next/previous token is not a word or does not exist.
Sourcepub fn fat_string_tokens(&self) -> impl Iterator<Item = FatStringToken> + '_
pub fn fat_string_tokens(&self) -> impl Iterator<Item = FatStringToken> + '_
Get an iterator over all the tokens contained in the document.
pub fn get_span_content(&self, span: &Span<char>) -> &[char]
pub fn get_span_content_str(&self, span: &Span<char>) -> String
pub fn get_full_string(&self) -> String
pub fn get_full_content(&self) -> &[char]
pub fn get_source(&self) -> &[char]
pub fn get_tokens(&self) -> &[Token]