VecExt

Trait VecExt 

pub trait VecExt: Sealed {
    // Required method
    fn remove_indices(&mut self, to_remove: VecDeque<usize>);
}
Extensions on top of Vec that make certain common operations easier.

Required Methods

fn remove_indices(&mut self, to_remove: VecDeque<usize>)

Removes a list of indices from a Vector. Assumes that the provided indices are already in sorted order.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> VecExt for Vec<T>

Source

fn remove_indices(&mut self, to_remove: VecDeque<usize>)

Implementors