Weirpack

Struct Weirpack 

pub struct Weirpack {
    pub rules: HashMap<String, String>,
    pub dictionary: Option<String>,
    pub annotations: Option<String>,
    pub manifest: WeirpackManifest,
}
A Weirpack, which carries within itself one or more rules to be used for grammar checking. These rules are written in Weir.

Fields

rules: HashMap<String, String>dictionary: Option<String>

The dictionary.dict file, if it exists.

annotations: Option<String>

The annotations.json file, if it exists.

manifest: WeirpackManifest

Implementations

Source

impl Weirpack

pub fn new(manifest: WeirpackManifest) -> Self

Create an empty Weirpack.

pub fn add_rule( &mut self, name: impl Into<String>, rule: impl Into<String>, ) -> Option<String>

Add a rule to this Weirpack. Does not compile to test the rule.

pub fn remove_rule(&mut self, name: &str) -> Option<String>

Remove a rule from this Weirpack.

pub fn run_tests(&self) -> Result<HashMap<String, Vec<TestResult>>, Error>

Run all the tests within all the Weir rules in this Weirpack.

pub fn to_lint_group(&self) -> Result<LintGroup, Error>

Parse and optimize the Weir rules in the pack, converting the set into a single LintGroup. Does not run tests.

pub fn from_reader(reader: impl Read) -> Result<Self, Error>

Load a Weirpack from bytes.

pub fn write_to(&self, writer: impl Write) -> Result<(), Error>

Write the Weirpack to bytes.

pub fn load_dictionary(&self) -> Result<Option<MutableDictionary>, Error>

Loads the dictionary that may or may not be contained within the Weirpack.

The dictionary is in the Rune format and thus is composed of two files, annotations.json and dictionary.dict.

Returns None if the relevant files are not present in the Weirpack.

pub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>

Load a Weirpack from bytes.

pub fn to_bytes(&self) -> Result<Vec<u8>, Error>

Write a Weirpack into bytes.