pub trait VecExt: Sealed {
// Required method
fn remove_indices(&mut self, to_remove: VecDeque<usize>);
}Expand description
Extensions on top of Vec that make certain common operations easier.
Required Methods
Sourcefn remove_indices(&mut self, to_remove: VecDeque<usize>)
fn remove_indices(&mut self, to_remove: VecDeque<usize>)
Removes a list of indices from a Vector. Assumes that the provided indices are already in sorted order.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".